pub fn subprocess_verify(
bundle_data: &[u8],
timeout: Duration,
) -> Result<SubprocessResult>Expand description
Verify a bundle by writing it to a temp file and invoking assay evidence verify.
Returns SubprocessResult indicating whether the bundle was accepted or rejected.
The caller’s process is never at risk of panics or aborts from the verifier.